StreamCollection

Struct StreamCollection 

pub struct StreamCollection { /* private fields */ }
Container of per-kind, indexed-by-position streams.

Implementations

Source

impl StreamCollection

pub fn new() -> Self

pub fn stream_prepare(&mut self, kind: StreamKind) -> usize

Allocate a new stream of kind, return its StreamPos. Matches File__Analyze::Stream_Prepare.

pub fn stream_count(&self, kind: StreamKind) -> usize

pub fn set_field( &mut self, kind: StreamKind, pos: usize, parameter: &str, value: impl Into<Ztring>, )

Set a field on a stream. If the field already exists, it is NOT overwritten (first-write-wins). Auto-creates the stream if it doesn’t exist yet.

pub fn force_field( &mut self, kind: StreamKind, pos: usize, parameter: &str, value: impl Into<Ztring>, )

Set a field on a stream, ALWAYS overwriting any existing value. Auto-creates the stream if it doesn’t exist yet.

pub fn set_extra_field( &mut self, kind: StreamKind, pos: usize, parameter: &str, value: impl Into<Ztring>, )

Set a field in the stream’s <extra> bucket instead of the standard field list. First-write-wins.

pub fn force_extra_field( &mut self, kind: StreamKind, pos: usize, parameter: &str, value: impl Into<Ztring>, )

Like [set_extra_field], but ALWAYS overwrites.

pub fn retrieve( &self, kind: StreamKind, pos: usize, parameter: &str, ) -> Option<&Ztring>

pub fn stream(&self, kind: StreamKind, pos: usize) -> Option<&Stream>

pub fn filter_keep( &mut self, keep: &[StreamKind], specific: &[(StreamKind, usize)], )

Remove all streams whose StreamKind is not in keep, and remove all streams at a kind whose positional index is not in positions (when that map entry exists). Used to implement --video-only, --audio-only, and --stream filtering.

pub fn iter(&self) -> impl Iterator<Item = (StreamKind, usize, &Stream)>